act.qc.qctests.QCTests
======================

.. currentmodule:: act.qc.qctests

.. autoclass:: QCTests

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~QCTests.__init__
      ~QCTests.add_delta_test
      ~QCTests.add_difference_test
      ~QCTests.add_equal_to_test
      ~QCTests.add_greater_equal_test
      ~QCTests.add_greater_test
      ~QCTests.add_inside_test
      ~QCTests.add_less_equal_test
      ~QCTests.add_less_test
      ~QCTests.add_missing_value_test
      ~QCTests.add_not_equal_to_test
      ~QCTests.add_outside_test
      ~QCTests.add_persistence_test
   
   

   
   
   